#pragma once

#include "window.h"
#include "unassignable.h"
#include <string>
#include <list>

namespace rov2
{

class CIcon;

/*! Class to create an about box */
class CAboutBox : public CWindow
{
public:
  /*! Constructor for the about box
  \param rksName The value for the 'Name' field
  \param rksPurpose The value for the 'Purpose' field
  \param rksAuthor The value for the 'Author' field
  \param rksVersion The value for the 'Version' field
  */
  CAboutBox(const std::string& rksName, const std::string& rksPurpose, const std::string& rksAuthor, const std::string& rksVersion);

  /*! Destructor for the about box */
  ~CAboutBox();

protected:
  /*! Add a row to the about box
  \param rksHeader The row's name
  \param rksValue The row's value
  */
  void AddRow(const std::string& rksHeader, const std::string& rksValue);

  virtual void Adorn(tWindowCreateBlock& rwcbBlock);

  virtual void Created(void);

private:
  /*! The list of headers */
  std::list<const std::string*> m_lpsHeaders;

  /*! The list of values */
  std::list<const std::string*> m_lpsValues;

  /*! The list of icons that have been created */
  std::list<const CIcon*> m_liIcons;

  /*! The width of all the headers */
  tCoordinate m_cHeaderWidth;

  /*! The width of all the values */
  tCoordinate m_cValueWidth;

}; // ab

}