#pragma once

#include "clickable.h"
#include "wimp_menu.h"
#include "unassignable.h"
#include <string>

namespace rov2
{

typedef enum
{
  mhUnhandled,
  mhHandledClose,
  mhHandledKeepOpen,
  mhHandledKeepOpenRecreate
} eMenuHandled; // mh

class CMenu;
class CWindow;

/*! Defines a class that holds a generic menu item */
class CMenuItem : public CUnassignable
{
  /*! CMenu needs access to call PopulateMenu */
  friend class CMenu;

public:
  /*! True if the item is ticked */
  bool m_bTicked;

  /*! True if a dotted line appears after this item */
  bool m_bDotted;

  /*! Called when this item is clicked on 
  \param bAdjust True if ADJUST was used to select the item
  \param pContext The context from the menu which was clicked on
  \return True if this selection was handled by this code (otherwise parent items are called)
  */
  virtual eMenuHandled Clicked(const bool bAdjust, void* pContext);

  /*! Attach a submenu to this item
  \param pmMenu The menu to attach
  */
  void AttachSubmenu(CMenu* pmMenu);

  /*! Attach a window as a submenu to this item
  \param pwWindow The window to attach
  */
  void AttachSubmenu(CWindow* pwWindow);

protected:
  /*! Creates a new menu item */
  CMenuItem();
  
  /*! Destroys a new menu item - note that it must be removed from any menus */
  ~CMenuItem();

  /*! Called to populate the menu.
  \param pmiItem Pointer to the WIMP menu item to fill in.
  \return The width (in OS units) of the item
  */
  virtual tCoordinate PopulateMenu(tMenuItem* pmiItem);

  /*! The submenu (if it's a menu) */
  CMenu* m_pmSubmenu;

  /*! The submenu (if it's a window) */
  CWindow* m_pwWindow;

private:
};

/*! Defines a basic text menu item */
class CTextMenuItem : public CMenuItem
{
public:
  /*! Constructor for the text menu item
  \param rksText Reference to the text string (which is copied internally)
  */
  CTextMenuItem(const std::string& rksText);
protected:
  virtual tCoordinate PopulateMenu(tMenuItem* pmiItem);
private:
  /*! The text */
  std::string m_sText;
};

}